@@ -15,6 +15,7 @@
 #  limitations under the License.
 
 import os
+from posixpath import split
 import sys
 import re
 from os import path
@@ -59,9 +60,8 @@ class DomainInfoHelper(VariableInterface):
     """
 
     def getUserDataInFile(self, login, filePasswd):
-        return filter(lambda x: x[0] == login,
-                      map(lambda x: x.strip().split(':'),
-                          readLinesFile(filePasswd)))
+        return [x for x in (y.strip().split(':') for y 
+            in readLinesFile(filePasswd)) if x[0] == login]
 
     def isDomainUser(self, userName):
         if userName:
@@ -93,9 +93,8 @@ class VariableUrDomainSet(ReadonlyVariable, DomainInfoHelper):
     type = "bool"
 
     def getUserDataInFile(self, login, file_passwd):
-        return filter(lambda x: x[0] == login,
-                      map(lambda x: x.strip().split(':'),
-                          readLinesFile(file_passwd)))
+        return [x for x in (y.strip().split(':') for y 
+            in readLinesFile(file_passwd)) if x[0] == login]
 
     def get(self):
         return "on" if self.isDomainUser(self.Get('ur_login')) else "off"
@@ -156,10 +155,9 @@ class VariableClDesktopGstData(ReadonlyVariable):
             if res == gst.STATE_CHANGE_SUCCESS:
                 outdata['device_name'] = alsamixer.get_property("device-name")
                 outdata['long_name'] = alsamixer.get_factory().get_longname()
-                outdata['internal_name'] = filter(str.isalnum,
-                                                  "%s (%s)" % (
-                                                      outdata['device_name'],
-                                                      outdata['long_name']))
+                outdata['internal_name'] = [x for x 
+                    in "%s (%s)" % (outdata['device_name'],outdata['long_name']) 
+                    if str.isalnum(x)]
                 outdata['channels'] = []
                 for t in alsamixer.list_tracks():
                     if t.flags & gst.interfaces.MIXER_TRACK_OUTPUT:
@@ -200,9 +198,8 @@ class VariableClDesktopXfceMixer(ReadonlyVariable):
     """
 
     def get(self):
-        return "\n".join(
-            map(lambda x: '      <value type="string" value="%s" />' % x,
-                self.Get('cl_desktop_gst_data').get('channels', [])))
+        return "\n".join(('      <value type="string" value="%s" />' % x for x 
+            in self.Get('cl_desktop_gst_data').get('channels', [])))
 
 
 class VariableClDesktopXfcePointers(ReadonlyVariable):
@@ -257,25 +254,32 @@ class VariableClDesktopOnlineData(ReadonlyTableVariable, DomainInfoHelper):
         if resWho.success():
             listProcessing = lambda x: (x[0], x[1], x[-1]) \
                 if len(x) >= 5 else []
+            # xData = groupby(
+            #     sorted(
+            #         filter(lambda x: x[0] != "root",
+            #                map(lambda x: (x[0], self._getDisplay(x[1], x[2])),
+            #                    filter(lambda x: x and \
+            #                                     (x[2].startswith("(:") or
+            #                                      x[1].startswith(":")),
+            #                           map(lambda x: listProcessing(
+            #                               list(filter(lambda y: y, x.split()))),
+            #                               resWho)))),
+            #         key=lambda x: x[0]),
+            #     lambda x: x[0])
+
             xData = groupby(
-                sorted(
-                    filter(lambda x: x[0] != "root",
-                           map(lambda x: (x[0], self._getDisplay(x[1], x[2])),
-                               filter(lambda x: x and \
-                                                (x[2].startswith("(:") or
-                                                 x[1].startswith(":")),
-                                      map(lambda x: listProcessing(
-                                          filter(lambda y: y, x.split())),
-                                          resWho)))),
-                    key=lambda x: x[0]),
+                sorted((x for x in ((y[0], self._getDisplay(y[1], y[2])) for y 
+                            in (listProcessing([o for o in z.split() if o]) for z 
+                                in resWho) 
+                            if y and (y[2].startswith("(:") or y[1].startswith(":"))) 
+                        if x[0] != "root"),
+                    key=lambda x: x[0]), 
                 lambda x: x[0])
-            xData = map(lambda x: (x[0][0], x[0][1],
-                                   self.get_user_uid(x[0][0]),
-                                   "on" if self.isDomainUser(
-                                       x[0][0]) else "off",
-                                   len(x)),
-                        map(lambda x: list(x[1]),
-                            xData))
+
+
+            xData = [(x[0][0], x[0][1], self.get_user_uid(x[0][0]), "on" 
+                if self.isDomainUser(x[0][0]) else "off", len(x)) for x 
+                    in (list(y[1]) for y in xData)]
         return xData
 
     setValue = Variable.setValue
@@ -367,13 +371,14 @@ class VariableUrMountDirs(ReadonlyVariable):
         mountProfileDir = path.join(dirStart, ".%s" % dirEnd)
         mountRemoteProfileDir = path.join(dirStart, ".%s.remote" % dirEnd)
 
-        directories = filter(lambda x: x != homeDir,
-                             filter(lambda x: (x.startswith(homeDir) or
-                                               x.startswith(mountProfileDir) or
-                                               x.startswith(
-                                                   mountRemoteProfileDir)),
-                                    map(lambda x: x.split(" ")[1],
-                                        readLinesFile('/proc/mounts'))))
+        directories = (x for x 
+            in (y for y 
+                in (z.split(" ")[1] for z 
+                    in readLinesFile('/proc/mounts')) 
+                if (y.startswith(homeDir) 
+                or y.startswith(mountProfileDir) 
+                or y.startswith(mountRemoteProfileDir))) 
+            if x != homeDir)
         # if isMount(homeDir):
         #    directories.append(homeDir)
         return sorted(directories, reverse=True)
@@ -446,9 +451,8 @@ class VariableClDesktopFaceList(Variable):
     type = "list"
 
     def get(self):
-        return sorted(
-            filter(lambda x: x.endswith('.png'),
-                   listDirectory(self.Get('cl_desktop_face_path'))))
+        return sorted((x for x in listDirectory(self.Get('cl_desktop_face_path')) 
+            if x.endswith('.png')))
 
 
 class VariableClDesktopHashFace(Variable):
@@ -461,11 +465,10 @@ class VariableClDesktopHashFace(Variable):
         login = self.Get('ur_login')
         icon_list = self.Get('cl_desktop_face_list')
         if icon_list:
+            # return path.join(self.Get('cl_desktop_face_path'),
+            #                  icon_list[sum(map(lambda x: ord(x), hashlib.md5(login).digest())) % len(icon_list)])
             return path.join(self.Get('cl_desktop_face_path'),
-                             icon_list[sum(map(lambda x: ord(x),
-                                               hashlib.md5(
-                                                   login).digest())) % len(
-                                 icon_list)])
+                             icon_list[sum([x for x in hashlib.md5(login.encode("UTF-8")).digest()]) % len(icon_list)])
         else:
             return ""
 
